summaryrefslogtreecommitdiffstats
path: root/src/host/layer23/include/osmocom/bb/mobile/settings.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/host/layer23/include/osmocom/bb/mobile/settings.h')
-rw-r--r--src/host/layer23/include/osmocom/bb/mobile/settings.h2
1 files changed, 1 insertions, 1 deletions
diff --git a/src/host/layer23/include/osmocom/bb/mobile/settings.h b/src/host/layer23/include/osmocom/bb/mobile/settings.h
index 6d446967..fae12202 100644
--- a/src/host/layer23/include/osmocom/bb/mobile/settings.h
+++ b/src/host/layer23/include/osmocom/bb/mobile/settings.h
@@ -83,7 +83,7 @@ struct gsm_settings {
uint8_t half_v1;
uint8_t half_v3;
uint8_t ch_cap; /* channel capability */
- int8_t min_rxlev_db; /* min DB to access */
+ int8_t min_rxlev_dbm; /* min dBm to access */
/* radio */
uint16_t dsc_max;